Learn how to use the program with the following methods:

- [Using through a terminal](using-through-terminal.md) - This is the most recommended ones as this is the intended and the most easiest way.
- [Using through a script](using-through-a-script.md) - Preferred method for those who need flexibility (e.g., downloading multiple live streams from different users all at once), but this requires more technical knowledge.
